﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using HeuristicLab.Collections;
using HeuristicLab.Common;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Hive.Contracts.BusinessObjects {
  [StorableClass]
  [Serializable]
  public class SerializedJobList : ObservableList<SerializedJob>, IDeepCloneable {
    public SerializedJobList() { }
    public SerializedJobList(IEnumerable<SerializedJob> collection) {
      this.list = new List<SerializedJob>(collection);
    }
    [StorableConstructor]
    protected SerializedJobList(bool deserializing) : base(deserializing) { }
    protected SerializedJobList(SerializedJobList original, Cloner cloner) {
      cloner.RegisterClonedObject(original, this);
      this.list = (original.Select(x => cloner.Clone(x))).ToList();
    }
    public virtual IDeepCloneable Clone(Cloner cloner) {
      return new SerializedJobList(this, cloner);
    }
    public object Clone() {
      return Clone(new Cloner());
    }
  }
}